/****************************************************************************
** Meta object code from reading C++ file 'anything_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../3rdparty/interfaces/anything_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'anything_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ComDeepinAnythingInterface_t {
    QByteArrayData data[48];
    char stringdata0[664];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ComDeepinAnythingInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ComDeepinAnythingInterface_t qt_meta_stringdata_ComDeepinAnythingInterface = {
    {
QT_MOC_LITERAL(0, 0, 26), // "ComDeepinAnythingInterface"
QT_MOC_LITERAL(1, 27, 15), // "addPathFinished"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 4), // "path"
QT_MOC_LITERAL(4, 49, 7), // "success"
QT_MOC_LITERAL(5, 57, 7), // "addPath"
QT_MOC_LITERAL(6, 65, 23), // "QDBusPendingReply<bool>"
QT_MOC_LITERAL(7, 89, 7), // "allPath"
QT_MOC_LITERAL(8, 97, 30), // "QDBusPendingReply<QStringList>"
QT_MOC_LITERAL(9, 128, 8), // "cacheDir"
QT_MOC_LITERAL(10, 137, 26), // "QDBusPendingReply<QString>"
QT_MOC_LITERAL(11, 164, 11), // "cancelBuild"
QT_MOC_LITERAL(12, 176, 6), // "hasLFT"
QT_MOC_LITERAL(13, 183, 20), // "hasLFTSubdirectories"
QT_MOC_LITERAL(14, 204, 18), // "insertFileToLFTBuf"
QT_MOC_LITERAL(15, 223, 8), // "filePath"
QT_MOC_LITERAL(16, 232, 11), // "lftBuinding"
QT_MOC_LITERAL(17, 244, 14), // "parallelsearch"
QT_MOC_LITERAL(18, 259, 40), // "QDBusPendingReply<QStringList..."
QT_MOC_LITERAL(19, 300, 11), // "startOffset"
QT_MOC_LITERAL(20, 312, 9), // "endOffset"
QT_MOC_LITERAL(21, 322, 7), // "keyword"
QT_MOC_LITERAL(22, 330, 5), // "rules"
QT_MOC_LITERAL(23, 336, 23), // "QDBusReply<QStringList>"
QT_MOC_LITERAL(24, 360, 5), // "uint&"
QT_MOC_LITERAL(25, 366, 12), // "startOffset_"
QT_MOC_LITERAL(26, 379, 10), // "endOffset_"
QT_MOC_LITERAL(27, 390, 4), // "quit"
QT_MOC_LITERAL(28, 395, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(29, 415, 7), // "refresh"
QT_MOC_LITERAL(30, 423, 15), // "serialUriFilter"
QT_MOC_LITERAL(31, 439, 20), // "removeFileFromLFTBuf"
QT_MOC_LITERAL(32, 460, 10), // "removePath"
QT_MOC_LITERAL(33, 471, 18), // "renameFileOfLFTBuf"
QT_MOC_LITERAL(34, 490, 12), // "fromFilePath"
QT_MOC_LITERAL(35, 503, 10), // "toFilePath"
QT_MOC_LITERAL(36, 514, 6), // "search"
QT_MOC_LITERAL(37, 521, 8), // "maxCount"
QT_MOC_LITERAL(38, 530, 5), // "icase"
QT_MOC_LITERAL(39, 536, 9), // "useRegExp"
QT_MOC_LITERAL(40, 546, 21), // "setCodecNameForLocale"
QT_MOC_LITERAL(41, 568, 29), // "QDBusPendingReply<QByteArray>"
QT_MOC_LITERAL(42, 598, 4), // "name"
QT_MOC_LITERAL(43, 603, 4), // "sync"
QT_MOC_LITERAL(44, 608, 10), // "mountPoint"
QT_MOC_LITERAL(45, 619, 17), // "autoIndexExternal"
QT_MOC_LITERAL(46, 637, 17), // "autoIndexInternal"
QT_MOC_LITERAL(47, 655, 8) // "logLevel"

    },
    "ComDeepinAnythingInterface\0addPathFinished\0"
    "\0path\0success\0addPath\0QDBusPendingReply<bool>\0"
    "allPath\0QDBusPendingReply<QStringList>\0"
    "cacheDir\0QDBusPendingReply<QString>\0"
    "cancelBuild\0hasLFT\0hasLFTSubdirectories\0"
    "insertFileToLFTBuf\0filePath\0lftBuinding\0"
    "parallelsearch\0QDBusPendingReply<QStringList,uint,uint>\0"
    "startOffset\0endOffset\0keyword\0rules\0"
    "QDBusReply<QStringList>\0uint&\0"
    "startOffset_\0endOffset_\0quit\0"
    "QDBusPendingReply<>\0refresh\0serialUriFilter\0"
    "removeFileFromLFTBuf\0removePath\0"
    "renameFileOfLFTBuf\0fromFilePath\0"
    "toFilePath\0search\0maxCount\0icase\0"
    "useRegExp\0setCodecNameForLocale\0"
    "QDBusPendingReply<QByteArray>\0name\0"
    "sync\0mountPoint\0autoIndexExternal\0"
    "autoIndexInternal\0logLevel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ComDeepinAnythingInterface[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       3,  244, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  124,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,  129,    2, 0x0a /* Public */,
       7,    0,  132,    2, 0x0a /* Public */,
       9,    0,  133,    2, 0x0a /* Public */,
      11,    1,  134,    2, 0x0a /* Public */,
      12,    1,  137,    2, 0x0a /* Public */,
      13,    1,  140,    2, 0x0a /* Public */,
      14,    1,  143,    2, 0x0a /* Public */,
      16,    1,  146,    2, 0x0a /* Public */,
      17,    5,  149,    2, 0x0a /* Public */,
      17,    7,  160,    2, 0x0a /* Public */,
      17,    3,  175,    2, 0x0a /* Public */,
      27,    0,  182,    2, 0x0a /* Public */,
      29,    1,  183,    2, 0x0a /* Public */,
      31,    1,  186,    2, 0x0a /* Public */,
      32,    1,  189,    2, 0x0a /* Public */,
      33,    2,  192,    2, 0x0a /* Public */,
      36,    7,  197,    2, 0x0a /* Public */,
      36,    9,  212,    2, 0x0a /* Public */,
      36,    3,  231,    2, 0x0a /* Public */,
      40,    1,  238,    2, 0x0a /* Public */,
      43,    1,  241,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    3,    4,

 // slots: parameters
    0x80000000 | 6, QMetaType::QString,    3,
    0x80000000 | 8,
    0x80000000 | 10,
    0x80000000 | 6, QMetaType::QString,    3,
    0x80000000 | 6, QMetaType::QString,    3,
    0x80000000 | 8, QMetaType::QString,    3,
    0x80000000 | 8, QMetaType::QByteArray,   15,
    0x80000000 | 6, QMetaType::QString,    3,
    0x80000000 | 18, QMetaType::QString, QMetaType::UInt, QMetaType::UInt, QMetaType::QString, QMetaType::QStringList,    3,   19,   20,   21,   22,
    0x80000000 | 23, QMetaType::QString, QMetaType::UInt, QMetaType::UInt, QMetaType::QString, QMetaType::QStringList, 0x80000000 | 24, 0x80000000 | 24,    3,   19,   20,   21,   22,   25,   26,
    0x80000000 | 8, QMetaType::QString, QMetaType::QString, QMetaType::QStringList,    3,   21,   22,
    0x80000000 | 28,
    0x80000000 | 8, QMetaType::QByteArray,   30,
    0x80000000 | 8, QMetaType::QByteArray,   15,
    0x80000000 | 6, QMetaType::QString,    3,
    0x80000000 | 8, QMetaType::QByteArray, QMetaType::QByteArray,   34,   35,
    0x80000000 | 18, QMetaType::Int, QMetaType::LongLong, QMetaType::UInt, QMetaType::UInt, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   37,   38,   19,   20,    3,   21,   39,
    0x80000000 | 23, QMetaType::Int, QMetaType::LongLong, QMetaType::UInt, QMetaType::UInt, QMetaType::QString, QMetaType::QString, QMetaType::Bool, 0x80000000 | 24, 0x80000000 | 24,   37,   38,   19,   20,    3,   21,   39,   25,   26,
    0x80000000 | 8, QMetaType::QString, QMetaType::QString, QMetaType::Bool,    3,   21,   39,
    0x80000000 | 41, QMetaType::QByteArray,   42,
    0x80000000 | 8, QMetaType::QString,   44,

 // properties: name, type, flags
      45, QMetaType::Bool, 0x00095103,
      46, QMetaType::Bool, 0x00095103,
      47, QMetaType::Int, 0x00095103,

       0        // eod
};

void ComDeepinAnythingInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ComDeepinAnythingInterface *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->addPathFinished((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: { QDBusPendingReply<bool> _r = _t->addPath((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<QStringList> _r = _t->allPath();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->cacheDir();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->cancelBuild((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->hasLFT((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QStringList> _r = _t->hasLFTSubdirectories((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QStringList> _r = _t->insertFileToLFTBuf((*reinterpret_cast< const QByteArray(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->lftBuinding((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QStringList,uint,uint> _r = _t->parallelsearch((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QStringList(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList,uint,uint>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusReply<QStringList> _r = _t->parallelsearch((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QStringList(*)>(_a[5])),(*reinterpret_cast< uint(*)>(_a[6])),(*reinterpret_cast< uint(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QStringList> _r = _t->parallelsearch((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->quit();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QStringList> _r = _t->refresh((*reinterpret_cast< const QByteArray(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QStringList> _r = _t->removeFileFromLFTBuf((*reinterpret_cast< const QByteArray(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<bool> _r = _t->removePath((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QStringList> _r = _t->renameFileOfLFTBuf((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QStringList,uint,uint> _r = _t->search((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< uint(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList,uint,uint>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusReply<QStringList> _r = _t->search((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])),(*reinterpret_cast< uint(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7])),(*reinterpret_cast< uint(*)>(_a[8])),(*reinterpret_cast< uint(*)>(_a[9])));
            if (_a[0]) *reinterpret_cast< QDBusReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<QStringList> _r = _t->search((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QByteArray> _r = _t->setCodecNameForLocale((*reinterpret_cast< const QByteArray(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QByteArray>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QStringList> _r = _t->sync((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ComDeepinAnythingInterface::*)(const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ComDeepinAnythingInterface::addPathFinished)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ComDeepinAnythingInterface *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->autoIndexExternal(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->autoIndexInternal(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->logLevel(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ComDeepinAnythingInterface *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutoIndexExternal(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setAutoIndexInternal(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setLogLevel(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject ComDeepinAnythingInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_meta_stringdata_ComDeepinAnythingInterface.data,
    qt_meta_data_ComDeepinAnythingInterface,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ComDeepinAnythingInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComDeepinAnythingInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ComDeepinAnythingInterface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int ComDeepinAnythingInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 22;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ComDeepinAnythingInterface::addPathFinished(const QString & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
