/****************************************************************************
** Meta object code from reading C++ file 'grandsearchinterface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../dbusservice/grandsearchinterface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'grandsearchinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GrandSearch__GrandSearchInterface_t {
    QByteArrayData data[16];
    char stringdata0[205];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GrandSearch__GrandSearchInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GrandSearch__GrandSearchInterface_t qt_meta_stringdata_GrandSearch__GrandSearchInterface = {
    {
QT_MOC_LITERAL(0, 0, 33), // "GrandSearch::GrandSearchInter..."
QT_MOC_LITERAL(1, 34, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 50, 32), // "org.deepin.dde.GrandSearchDaemon"
QT_MOC_LITERAL(3, 83, 7), // "Matched"
QT_MOC_LITERAL(4, 91, 0), // ""
QT_MOC_LITERAL(5, 92, 7), // "session"
QT_MOC_LITERAL(6, 100, 15), // "SearchCompleted"
QT_MOC_LITERAL(7, 116, 6), // "Search"
QT_MOC_LITERAL(8, 123, 3), // "key"
QT_MOC_LITERAL(9, 127, 9), // "Terminate"
QT_MOC_LITERAL(10, 137, 14), // "MatchedResults"
QT_MOC_LITERAL(11, 152, 13), // "MatchedBuffer"
QT_MOC_LITERAL(12, 166, 14), // "OpenWithPlugin"
QT_MOC_LITERAL(13, 181, 8), // "searcher"
QT_MOC_LITERAL(14, 190, 4), // "item"
QT_MOC_LITERAL(15, 195, 9) // "KeepAlive"

    },
    "GrandSearch::GrandSearchInterface\0"
    "D-Bus Interface\0org.deepin.dde.GrandSearchDaemon\0"
    "Matched\0\0session\0SearchCompleted\0"
    "Search\0key\0Terminate\0MatchedResults\0"
    "MatchedBuffer\0OpenWithPlugin\0searcher\0"
    "item\0KeepAlive"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GrandSearch__GrandSearchInterface[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       8,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,   56,    4, 0x46 /* Public | isScriptable */,
       6,    1,   59,    4, 0x46 /* Public | isScriptable */,

 // slots: name, argc, parameters, tag, flags
       7,    2,   62,    4, 0x4a /* Public | isScriptable */,
       9,    0,   67,    4, 0x4a /* Public | isScriptable */,
      10,    1,   68,    4, 0x4a /* Public | isScriptable */,
      11,    1,   71,    4, 0x4a /* Public | isScriptable */,
      12,    2,   74,    4, 0x4a /* Public | isScriptable */,
      15,    1,   79,    4, 0x4a /* Public | isScriptable */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,    5,    8,
    QMetaType::Void,
    QMetaType::QByteArray, QMetaType::QString,    5,
    QMetaType::QByteArray, QMetaType::QString,    5,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,   13,   14,
    QMetaType::Bool, QMetaType::QString,    5,

       0        // eod
};

void GrandSearch::GrandSearchInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<GrandSearchInterface *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->Matched((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->SearchCompleted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: { bool _r = _t->Search((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->Terminate(); break;
        case 4: { QByteArray _r = _t->MatchedResults((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 5: { QByteArray _r = _t->MatchedBuffer((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->OpenWithPlugin((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->KeepAlive((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (GrandSearchInterface::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GrandSearchInterface::Matched)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (GrandSearchInterface::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GrandSearchInterface::SearchCompleted)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject GrandSearch::GrandSearchInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusService::staticMetaObject>(),
    qt_meta_stringdata_GrandSearch__GrandSearchInterface.data,
    qt_meta_data_GrandSearch__GrandSearchInterface,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *GrandSearch::GrandSearchInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GrandSearch::GrandSearchInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GrandSearch__GrandSearchInterface.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QDBusService::qt_metacast(_clname);
}

int GrandSearch::GrandSearchInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusService::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void GrandSearch::GrandSearchInterface::Matched(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void GrandSearch::GrandSearchInterface::SearchCompleted(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
